from __future__ import absolute_import
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: TSWPCommandArchives.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import TSPMessages_pb2 as TSPMessages__pb2
from . import TSSArchives_pb2 as TSSArchives__pb2
from . import TSDArchives_pb2 as TSDArchives__pb2
from . import TSDCommandArchives_pb2 as TSDCommandArchives__pb2
from . import TSKArchives_pb2 as TSKArchives__pb2
from . import TSWPArchives_pb2 as TSWPArchives__pb2
from . import TSWPArchives_sos_pb2 as TSWPArchives__sos__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='TSWPCommandArchives.proto',
  package='TSWP',
  syntax='proto2',
  serialized_options=None,
  serialized_pb=_b('\n\x19TSWPCommandArchives.proto\x12\x04TSWP\x1a\x11TSPMessages.proto\x1a\x11TSSArchives.proto\x1a\x11TSDArchives.proto\x1a\x18TSDCommandArchives.proto\x1a\x11TSKArchives.proto\x1a\x12TSWPArchives.proto\x1a\x16TSWPArchives_sos.proto\"\"\n\x13\x44ummyCommandArchive\x12\x0b\n\x03\x66oo\x18\x01 \x02(\r\"\xd9\x06\n\x12TextCommandArchive\x12\"\n\x05super\x18\x01 \x01(\x0b\x32\x13.TSK.CommandArchive\x12\x1f\n\x07storage\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x12/\n\x10undo_transaction\x18\x03 \x01(\x0b\x32\x15.TSWP.UndoTransaction\x12\x1e\n\x16restore_range_location\x18\x04 \x01(\r\x12\x1c\n\x14restore_range_length\x18\x05 \x01(\r\x12#\n\x1bredo_restore_range_location\x18\x06 \x01(\r\x12!\n\x19redo_restore_range_length\x18\x07 \x01(\r\x12\x1a\n\x12text_command_flags\x18\t \x01(\r\x12+\n\x04kind\x18\n \x01(\x0e\x32\x1d.TSWP.TextCommandArchive.Kind\"\xfd\x03\n\x04Kind\x12\x12\n\x0ekKindContained\x10\x00\x12\x14\n\x10kKindReplaceText\x10\x01\x12\x0e\n\nkKindPaste\x10\x02\x12\x17\n\x13kKindParagraphStyle\x10\x03\x12\x12\n\x0ekKindListStyle\x10\x04\x12\x1d\n\x19kKindIndentParagraphLevel\x10\x05\x12\x11\n\rkKindDragText\x10\x06\x12\x13\n\x0fkKindPasteStyle\x10\x07\x12\x1c\n\x18kKindApplyChangesInRange\x10\x08\x12\x1c\n\x18kKindInsertCitationField\x10\n\x12 \n\x1ckKindInsertBibliographyEntry\x10\x0b\x12\x1d\n\x19kKindFormatCitationFields\x10\x0c\x12\x1c\n\x18kKindInsertTOCSmartField\x10\r\x12\x1c\n\x18kKindInsertDateTimeField\x10\x0e\x12\x1c\n\x18kKindUpdateDateTimeField\x10\x0f\x12%\n!kKindSetParagraphFirstTopicNumber\x10\x10\x12\x17\n\x13kKindCharacterStyle\x10\x11\x12\x15\n\x11kKindRevertStyles\x10\x12\x12\x19\n\x15kKindSetParagraphBidi\x10\x13\"\xf8\x0b\n\x1bStorageActionCommandArchive\x12\"\n\x05super\x18\x01 \x01(\x0b\x32\x13.TSK.CommandArchive\x12\x1e\n\x07storage\x18\x02 \x01(\x0b\x32\r.TSP.UUIDPath\x12/\n\x10undo_transaction\x18\x03 \x01(\x0b\x32\x15.TSWP.UndoTransaction\x12\x1a\n\x12text_command_flags\x18\x04 \x01(\r\x12\x34\n\x04kind\x18\x05 \x01(\x0e\x32&.TSWP.StorageActionCommandArchive.Kind\x12%\n\x12\x63ustom_format_keys\x18\x06 \x03(\x0b\x32\t.TSP.UUID\x12\"\n\x1ais_forward_inverse_command\x18\x07 \x01(\x08\x12\x14\n\x0c\x63oalesceable\x18\x08 \x01(\x08\x12\x17\n\x0f\x63oalescing_text\x18\t \x01(\x08\x12\x1d\n\x15should_migrate_styles\x18\n \x01(\x08\x12?\n\x1d\x63hanged_data_reference_record\x18\x0b \x01(\x0b\x32\x18.TSK.DataReferenceRecord\x12\x1b\n\x13\x63oalescing_property\x18\x0c \x01(\t\"\x9a\x08\n\x04Kind\x12\x12\n\x0ekKindContained\x10\x00\x12\x14\n\x10kKindReplaceText\x10\x01\x12\x0e\n\nkKindPaste\x10\x02\x12\x17\n\x13kKindParagraphStyle\x10\x03\x12\x12\n\x0ekKindListStyle\x10\x04\x12\x1d\n\x19kKindIndentParagraphLevel\x10\x05\x12\x11\n\rkKindDragText\x10\x06\x12\x13\n\x0fkKindPasteStyle\x10\x07\x12\x1c\n\x18kKindApplyChangesInRange\x10\x08\x12\x1c\n\x18kKindInsertCitationField\x10\n\x12 \n\x1ckKindInsertBibliographyEntry\x10\x0b\x12\x1d\n\x19kKindFormatCitationFields\x10\x0c\x12\x1c\n\x18kKindInsertTOCSmartField\x10\r\x12\x1c\n\x18kKindInsertDateTimeField\x10\x0e\x12\x1c\n\x18kKindUpdateDateTimeField\x10\x0f\x12%\n!kKindSetParagraphFirstTopicNumber\x10\x10\x12\x17\n\x13kKindCharacterStyle\x10\x11\x12\x15\n\x11kKindRevertStyles\x10\x12\x12\x19\n\x15kKindSetParagraphBidi\x10\x13\x12\x13\n\x0fkKindFormatText\x10\x14\x12\x19\n\x15kKindInsertAttachment\x10\x15\x12\x18\n\x14kKindCreateHyperlink\x10\x16\x12\x18\n\x14kKindModifyHyperlink\x10\x17\x12\x18\n\x14kKindRemoveHyperlink\x10\x18\x12\x1b\n\x17kKindApplyHighlightText\x10\x19\x12\x1e\n\x1akKindPropagateStyleChanges\x10\x1a\x12$\n kKindMovedAnchoredDrawableInline\x10\x1b\x12\x1e\n\x1akKindMoveDrawablesAttached\x10\x1c\x12\"\n\x1ekKindMoveMoveDrawablesFloating\x10\x1d\x12#\n\x1fkKindMoveInlineDrawableAnchored\x10\x1e\x12\x19\n\x15kKindAnchorAttachment\x10\x1f\x12\x11\n\rkKindBookmark\x10 \x12\x17\n\x13kKindReplaceSection\x10!\x12\x1e\n\x1akKindApplyPencilAnnotation\x10\"\x12\x13\n\x0fkKindCreateRuby\x10#\x12\x13\n\x0fkKindModifyRuby\x10$\x12\x13\n\x0fkKindRemoveRuby\x10%\x12\x14\n\x10kKindTateChuYoko\x10&\x12\x15\n\x11kKindDropCapStyle\x10\'\"\x94\x01\n\x1cSetColumnStyleCommandArchive\x12\"\n\x05super\x18\x01 \x01(\x0b\x32\x13.TSK.CommandArchive\x12\x1f\n\x07storage\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x12/\n\x10undo_transaction\x18\x03 \x01(\x0b\x32\x15.TSWP.UndoTransaction\"\x9b\x01\n#ReplaceAllUsesOfStyleCommandArchive\x12\"\n\x05super\x18\x01 \x01(\x0b\x32\x13.TSK.CommandArchive\x12\x1f\n\x07storage\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x12/\n\x10undo_transaction\x18\x03 \x01(\x0b\x32\x15.TSWP.UndoTransaction\"\xbf\x01\n\x1bInsertColumnsCommandArchive\x12\"\n\x05super\x18\x01 \x01(\x0b\x32\x13.TSK.CommandArchive\x12\x1f\n\x07storage\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x12\x14\n\x0c\x63olumn_index\x18\x03 \x01(\r\x12\x14\n\x0c\x63olumn_count\x18\x04 \x01(\r\x12/\n\x10undo_transaction\x18\x05 \x01(\x0b\x32\x15.TSWP.UndoTransaction\"\xb6\x01\n\x18InsertRowsCommandArchive\x12\"\n\x05super\x18\x01 \x01(\x0b\x32\x13.TSK.CommandArchive\x12\x1f\n\x07storage\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x12\x11\n\trow_index\x18\x03 \x01(\r\x12\x11\n\trow_count\x18\x04 \x01(\r\x12/\n\x10undo_transaction\x18\x05 \x01(\x0b\x32\x15.TSWP.UndoTransaction\"\xbf\x01\n\x1bRemoveColumnsCommandArchive\x12\"\n\x05super\x18\x01 \x01(\x0b\x32\x13.TSK.CommandArchive\x12\x1f\n\x07storage\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x12\x14\n\x0c\x63olumn_index\x18\x03 \x01(\r\x12\x14\n\x0c\x63olumn_count\x18\x04 \x01(\r\x12/\n\x10undo_transaction\x18\x05 \x01(\x0b\x32\x15.TSWP.UndoTransaction\"\xb6\x01\n\x18RemoveRowsCommandArchive\x12\"\n\x05super\x18\x01 \x01(\x0b\x32\x13.TSK.CommandArchive\x12\x1f\n\x07storage\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x12\x11\n\trow_index\x18\x03 \x01(\r\x12\x11\n\trow_count\x18\x04 \x01(\r\x12/\n\x10undo_transaction\x18\x05 \x01(\x0b\x32\x15.TSWP.UndoTransaction\"\xd6\x01\n\x18MergeCellsCommandArchive\x12\"\n\x05super\x18\x01 \x01(\x0b\x32\x13.TSK.CommandArchive\x12\x1f\n\x07storage\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x12\x0b\n\x03row\x18\x03 \x01(\r\x12\x0e\n\x06\x63olumn\x18\x04 \x01(\r\x12\x11\n\trow_count\x18\x05 \x01(\r\x12\x14\n\x0c\x63olumn_count\x18\x06 \x01(\r\x12/\n\x10undo_transaction\x18\x07 \x01(\x0b\x32\x15.TSWP.UndoTransaction\"\xf0\x01\n\"ApplyPlaceholderTextCommandArchive\x12\"\n\x05super\x18\x01 \x01(\x0b\x32\x13.TSK.CommandArchive\x12\x1f\n\x07storage\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x12 \n\x18selection_range_location\x18\x03 \x01(\r\x12\x1e\n\x16selection_range_length\x18\x04 \x01(\r\x12/\n\x10undo_transaction\x18\x05 \x01(\x0b\x32\x15.TSWP.UndoTransaction\x12\x12\n\nscript_tag\x18\x06 \x01(\t\"\xa6\x02\n!UpdateDateTimeFieldCommandArchive\x12\'\n\x05super\x18\x01 \x01(\x0b\x32\x18.TSWP.TextCommandArchive\x12\'\n\x0f\x64\x61te_time_field\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x12\x17\n\x04\x64\x61te\x18\x03 \x01(\x0b\x32\t.TSP.Date\x12J\n\ndate_style\x18\x04 \x01(\x0e\x32\x36.TSWP.DateTimeSmartFieldArchive.DateTimeFormatterStyle\x12J\n\ntime_style\x18\x05 \x01(\x0e\x32\x36.TSWP.DateTimeSmartFieldArchive.DateTimeFormatterStyle\"\xe8\x01\n\x1b\x41pplyRubyTextCommandArchive\x12\"\n\x05super\x18\x01 \x01(\x0b\x32\x13.TSK.CommandArchive\x12\x1f\n\x07storage\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x12 \n\x18selection_range_location\x18\x03 \x01(\r\x12\x1e\n\x16selection_range_length\x18\x04 \x01(\r\x12\x11\n\truby_text\x18\x05 \x01(\t\x12/\n\x10undo_transaction\x18\x06 \x01(\x0b\x32\x15.TSWP.UndoTransaction\"\xbd\x01\n\x1cModifyRubyTextCommandArchive\x12\"\n\x05super\x18\x01 \x01(\x0b\x32\x13.TSK.CommandArchive\x12\"\n\nruby_field\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x12\x11\n\truby_text\x18\x03 \x01(\t\x12\x11\n\tbase_text\x18\x04 \x01(\t\x12/\n\x10undo_transaction\x18\x05 \x01(\x0b\x32\x15.TSWP.UndoTransaction\"\x9d\x01\n#ModifyTOCSettingsBaseCommandArchive\x12\"\n\x05super\x18\x01 \x01(\x0b\x32\x13.TSK.CommandArchive\x12(\n\x10old_toc_settings\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x12(\n\x10new_toc_settings\x18\x03 \x01(\x0b\x32\x0e.TSP.Reference\"\x90\x01\n)ModifyTOCSettingsForTOCInfoCommandArchive\x12\x38\n\x05super\x18\x01 \x01(\x0b\x32).TSWP.ModifyTOCSettingsBaseCommandArchive\x12)\n\x12toc_info_uuid_path\x18\x02 \x01(\x0b\x32\r.TSP.UUIDPath\"\x9e\x01\n-ModifyTOCSettingsPresetForThemeCommandArchive\x12\x38\n\x05super\x18\x01 \x01(\x0b\x32).TSWP.ModifyTOCSettingsBaseCommandArchive\x12\x1d\n\x05theme\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x12\x14\n\x0cpreset_index\x18\x03 \x01(\r\"\xdf\x02\n\x1e\x41nchorAttachmentCommandArchive\x12\x30\n\x05super\x18\x01 \x01(\x0b\x32!.TSWP.StorageActionCommandArchive\x12\"\n\nattachment\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x12\x15\n\rh_offset_type\x18\x03 \x01(\r\x12\x10\n\x08h_offset\x18\x04 \x01(\x02\x12\x15\n\rv_offset_type\x18\x05 \x01(\r\x12\x10\n\x08v_offset\x18\x06 \x01(\x02\x12\x14\n\x0cis_html_wrap\x18\x07 \x01(\x08\x12\x1a\n\x12undo_h_offset_type\x18\x08 \x01(\r\x12\x15\n\rundo_h_offset\x18\t \x01(\x02\x12\x1a\n\x12undo_v_offset_type\x18\n \x01(\r\x12\x15\n\rundo_v_offset\x18\x0b \x01(\x02\x12\x19\n\x11undo_is_html_wrap\x18\x0c \x01(\x08\"\xa3\x01\n\x1cTextApplyThemeCommandArchive\x12\x31\n\x05super\x18\x01 \x01(\x0b\x32\".TSS.ApplyThemeChildCommandArchive\x12\x1f\n\x07storage\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x12/\n\x10undo_transaction\x18\x06 \x01(\x0b\x32\x15.TSWP.UndoTransaction\"\xc6\x01\n\x19MoveColumnsCommandArchive\x12\"\n\x05super\x18\x01 \x01(\x0b\x32\x13.TSK.CommandArchive\x12\x1f\n\x07storage\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x12\x11\n\tsrc_index\x18\x03 \x01(\r\x12\x11\n\tdst_index\x18\x04 \x01(\r\x12\r\n\x05\x63ount\x18\x05 \x01(\r\x12/\n\x10undo_transaction\x18\x06 \x01(\x0b\x32\x15.TSWP.UndoTransaction\"\xc3\x01\n\x16MoveRowsCommandArchive\x12\"\n\x05super\x18\x01 \x01(\x0b\x32\x13.TSK.CommandArchive\x12\x1f\n\x07storage\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x12\x11\n\tsrc_index\x18\x03 \x01(\r\x12\x11\n\tdst_index\x18\x04 \x01(\r\x12\r\n\x05\x63ount\x18\x05 \x01(\r\x12/\n\x10undo_transaction\x18\x06 \x01(\x0b\x32\x15.TSWP.UndoTransaction\"w\n\x1eShapeApplyPresetCommandArchive\x12\x31\n\x05super\x18\x01 \x02(\x0b\x32\".TSD.BaseApplyPresetCommandArchive\x12\"\n\nundo_style\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\"{\n\x17StyleBaseCommandArchive\x12\"\n\x05super\x18\x01 \x01(\x0b\x32\x13.TSK.CommandArchive\x12\x1d\n\x05theme\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x12\x1d\n\x05style\x18\x03 \x01(\x0b\x32\x0e.TSP.Reference\"_\n\x19StyleCreateCommandArchive\x12,\n\x05super\x18\x01 \x01(\x0b\x32\x1d.TSWP.StyleBaseCommandArchive\x12\x14\n\x0cpreset_index\x18\x02 \x01(\r\"q\n\x19StyleRenameCommandArchive\x12,\n\x05super\x18\x01 \x01(\x0b\x32\x1d.TSWP.StyleBaseCommandArchive\x12\x14\n\x0cupdated_name\x18\x02 \x01(\t\x12\x10\n\x08old_name\x18\x03 \x01(\t\"\x98\x01\n\x19StyleUpdateCommandArchive\x12,\n\x05super\x18\x01 \x01(\x0b\x32\x1d.TSWP.StyleBaseCommandArchive\x12&\n\x0eoriginal_style\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x12%\n\rupdated_style\x18\x03 \x01(\x0b\x32\x0e.TSP.Reference\"c\n\x19StyleDeleteCommandArchive\x12,\n\x05super\x18\x01 \x01(\x0b\x32\x1d.TSWP.StyleBaseCommandArchive\x12\x18\n\x10old_preset_index\x18\x02 \x01(\r\"~\n\x1aStyleReorderCommandArchive\x12,\n\x05super\x18\x01 \x01(\x0b\x32\x1d.TSWP.StyleBaseCommandArchive\x12\x18\n\x10old_preset_index\x18\x02 \x01(\r\x12\x18\n\x10new_preset_index\x18\x03 \x01(\r\"`\n$StyleUpdatePropertyMapCommandArchive\x12\x38\n\x05super\x18\x01 \x02(\x0b\x32).TSS.StyleUpdatePropertyMapCommandArchive\"\x91\x01\n ShapeStyleSetValueCommandArchive\x12\x33\n\x05super\x18\x01 \x02(\x0b\x32$.TSD.BaseStyleSetValueCommandArchive\x12\x38\n\x06\x63hange\x18\x04 \x01(\x0b\x32(.TSWP.ShapeStylePropertyChangeSetArchive\"\x87\x01\n\x1bSelectionTransformerArchive\x12(\n\x11storage_uuid_path\x18\x01 \x02(\x0b\x32\r.TSP.UUIDPath\x12!\n\tselection\x18\x02 \x02(\x0b\x32\x0e.TSP.Reference\x12\x1b\n\x13transformed_to_noop\x18\x03 \x01(\x08\"|\n+PencilAnnotationSelectionTransformerArchive\x12(\n\x11storage_uuid_path\x18\x01 \x02(\x0b\x32\r.TSP.UUIDPath\x12#\n\x1btext_pencil_annotation_uuid\x18\x02 \x02(\t\"\x82\x01\n ShapeSelectionTransformerArchive\x12\x34\n\x05super\x18\x01 \x02(\x0b\x32%.TSD.ShapeSelectionTransformerArchive\x12(\n\x11storage_uuid_path\x18\x02 \x01(\x0b\x32\r.TSP.UUIDPath\"\x81\x01\n\x17ShapeContentDescription\x12.\n\x05super\x18\x01 \x02(\x0b\x32\x1f.TSD.DrawableContentDescription\x12\x1b\n\x13text_range_location\x18\x02 \x01(\r\x12\x19\n\x11text_range_length\x18\x03 \x01(\r\"\xba\x02\n\x15ObjectPropertyArchive\x12\x0c\n\x04name\x18\x01 \x02(\t\x12&\n\x04type\x18\x02 \x02(\x0e\x32\x18.TSWP.ObjectPropertyType\x12\x12\n\nbool_value\x18\x03 \x01(\x08\x12\x13\n\x0b\x66loat_value\x18\x04 \x01(\x02\x12\x15\n\rinteger_value\x18\x05 \x01(\x05\x12\x14\n\x0cstring_value\x18\x06 \x01(\t\x12$\n\rid_path_value\x18\x07 \x01(\x0b\x32\r.TSP.UUIDPath\x12$\n\nfill_value\x18\x08 \x01(\x0b\x32\x10.TSD.FillArchive\x12\x1f\n\x0b\x63olor_value\x18\t \x01(\x0b\x32\n.TSP.Color\x12(\n\x0cshadow_value\x18\n \x01(\x0b\x32\x12.TSD.ShadowArchive\"\xed\x01\n!SetObjectPropertiesCommandArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12\'\n\x10object_uuid_path\x18\x02 \x02(\x0b\x32\r.TSP.UUIDPath\x12/\n\nproperties\x18\x03 \x03(\x0b\x32\x1b.TSWP.ObjectPropertyArchive\x12\x15\n\raction_string\x18\x04 \x01(\t\x12\x33\n\x0eold_properties\x18\x05 \x03(\x0b\x32\x1b.TSWP.ObjectPropertyArchive\"\xb9\x04\n\x1cUpdateFlowInfoCommandArchive\x12\"\n\x05super\x18\x01 \x01(\x0b\x32\x13.TSK.CommandArchive\x12=\n\x0c\x63ommand_mode\x18\x02 \x01(\x0e\x32\'.TSWP.UpdateFlowInfoCommandArchive.Mode\x12*\n\x13\x66low_info_uuid_path\x18\x03 \x01(\x0b\x32\r.TSP.UUIDPath\x12\x38\n!text_box_id_path_to_add_or_remove\x18\x04 \x01(\x0b\x32\r.TSP.UUIDPath\x12\x31\n\x1atext_box_id_paths_at_start\x18\x05 \x03(\x0b\x32\r.TSP.UUIDPath\x12\x39\n\"suggested_text_box_id_paths_at_end\x18\x06 \x03(\x0b\x32\r.TSP.UUIDPath\x12\x32\n\x1aundo_text_boxes_to_restore\x18\x07 \x03(\x0b\x32\x0e.TSP.Reference\x12-\n\x15undo_added_shape_info\x18\x08 \x01(\x0b\x32\x0e.TSP.Reference\x12/\n\x17undo_removed_shape_info\x18\t \x01(\x0b\x32\x0e.TSP.Reference\"N\n\x04Mode\x12\x12\n\x0ekModeRearrange\x10\x00\x12\x0c\n\x08kModeAdd\x10\x01\x12\x0f\n\x0bkModeRemove\x10\x02\x12\x13\n\x0fkModeCompensate\x10\x03\"\xac\x02\n\x19\x41\x64\x64\x46lowInfoCommandArchive\x12\"\n\x05super\x18\x01 \x01(\x0b\x32\x13.TSK.CommandArchive\x12(\n\x10\x66low_info_to_add\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x12)\n\x11\x66low_info_archive\x18\x03 \x01(\x0b\x32\x0e.TSP.Reference\x12\x31\n)undo_user_interface_identifier_to_restore\x18\x04 \x01(\r\x12\x36\n.undo_next_user_interface_identifier_to_restore\x18\x05 \x01(\r\x12+\n\x13working_undo_object\x18\x06 \x01(\x0b\x32\x0e.TSP.Reference\"\xfe\x01\n\x1cRemoveFlowInfoCommandArchive\x12\"\n\x05super\x18\x01 \x01(\x0b\x32\x13.TSK.CommandArchive\x12*\n\x13\x66low_info_uuid_path\x18\x02 \x01(\x0b\x32\r.TSP.UUIDPath\x12#\n\x0bundo_object\x18\x03 \x01(\x0b\x32\x0e.TSP.Reference\x12\x31\n)undo_user_interface_identifier_to_restore\x18\x04 \x01(\r\x12\x36\n.undo_next_user_interface_identifier_to_restore\x18\x05 \x01(\r\"\xc3\x02\n\x1eTextCommentReplyCommandArchive\x12\"\n\x05super\x18\x01 \x01(\x0b\x32\x13.TSK.CommandArchive\x12(\n\x11storage_uuid_path\x18\x02 \x01(\x0b\x32\r.TSP.UUIDPath\x12\x17\n\x0f\x61nnotation_uuid\x18\x03 \x01(\t\x12\'\n\x0f\x66orward_comment\x18\x04 \x01(\x0b\x32\x0e.TSP.Reference\x12\'\n\x0finverse_comment\x18\x05 \x01(\x0b\x32\x0e.TSP.Reference\x12\x33\n\x0f\x66orward_variant\x18\x06 \x01(\x0e\x32\x1a.TSD.CommentCommandVariant\x12\x33\n\x0finverse_variant\x18\x07 \x01(\x0e\x32\x1a.TSD.CommentCommandVariant\"\xfc\x05\n\x1e\x43ontainedObjectsCommandArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12\x1e\n\x06target\x18\x02 \x02(\x0b\x32\x0e.TSP.Reference\x12\x1f\n\x07objects\x18\x03 \x03(\x0b\x32\x0e.TSP.Reference\x12\x30\n\x16undo_object_for_commit\x18\x04 \x01(\x0b\x32\x0e.TSP.ReferenceH\x00\x12\x36\n\x1cundo_object_for_make_inverse\x18\x05 \x01(\x0b\x32\x0e.TSP.ReferenceH\x00\x12Q\n\x11\x61\x64\x64_behavior_args\x18\x06 \x01(\x0b\x32\x34.TSWP.ContainedObjectsCommandArchive.AddBehaviorArgsH\x01\x12W\n\x14remove_behavior_args\x18\x07 \x01(\x0b\x32\x37.TSWP.ContainedObjectsCommandArchive.RemoveBehaviorArgsH\x01\x12]\n\x17rearrange_behavior_args\x18\x08 \x01(\x0b\x32:.TSWP.ContainedObjectsCommandArchive.RearrangeBehaviorArgsH\x01\x12\x16\n\x0e\x63ontainer_name\x18\t \x01(\t\x1a=\n\x0f\x41\x64\x64\x42\x65haviorArgs\x12*\n\targs_list\x18\x01 \x03(\x0b\x32\x17.TSK.AddIdOperationArgs\x1a\x43\n\x12RemoveBehaviorArgs\x12-\n\targs_list\x18\x01 \x03(\x0b\x32\x1a.TSK.RemoveIdOperationArgs\x1aI\n\x15RearrangeBehaviorArgs\x12\x30\n\targs_list\x18\x01 \x03(\x0b\x32\x1d.TSK.RearrangeIdOperationArgsB\r\n\x0bundo_objectB\n\n\x08\x62\x65havior\"Y\n\"EquationInfoGeometryCommandArchive\x12\x33\n\x05super\x18\x01 \x01(\x0b\x32$.TSD.MediaInfoGeometryCommandArchive*\x87\x02\n\x12ObjectPropertyType\x12\x1b\n\x17kObjectPropertyTypeBool\x10\x00\x12\x1c\n\x18kObjectPropertyTypeFloat\x10\x01\x12\x1e\n\x1akObjectPropertyTypeInteger\x10\x02\x12\x1d\n\x19kObjectPropertyTypeString\x10\x03\x12\x1d\n\x19kObjectPropertyTypeIdPath\x10\x04\x12\x1b\n\x17kObjectPropertyTypeFill\x10\x05\x12\x1c\n\x18kObjectPropertyTypeColor\x10\x06\x12\x1d\n\x19kObjectPropertyTypeShadow\x10\x07')
  ,
  dependencies=[TSPMessages__pb2.DESCRIPTOR,TSSArchives__pb2.DESCRIPTOR,TSDArchives__pb2.DESCRIPTOR,TSDCommandArchives__pb2.DESCRIPTOR,TSKArchives__pb2.DESCRIPTOR,TSWPArchives__pb2.DESCRIPTOR,TSWPArchives__sos__pb2.DESCRIPTOR,])

_OBJECTPROPERTYTYPE = _descriptor.EnumDescriptor(
  name='ObjectPropertyType',
  full_name='TSWP.ObjectPropertyType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='kObjectPropertyTypeBool', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kObjectPropertyTypeFloat', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kObjectPropertyTypeInteger', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kObjectPropertyTypeString', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kObjectPropertyTypeIdPath', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kObjectPropertyTypeFill', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kObjectPropertyTypeColor', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kObjectPropertyTypeShadow', index=7, number=7,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=10737,
  serialized_end=11000,
)
_sym_db.RegisterEnumDescriptor(_OBJECTPROPERTYTYPE)

ObjectPropertyType = enum_type_wrapper.EnumTypeWrapper(_OBJECTPROPERTYTYPE)
kObjectPropertyTypeBool = 0
kObjectPropertyTypeFloat = 1
kObjectPropertyTypeInteger = 2
kObjectPropertyTypeString = 3
kObjectPropertyTypeIdPath = 4
kObjectPropertyTypeFill = 5
kObjectPropertyTypeColor = 6
kObjectPropertyTypeShadow = 7


_TEXTCOMMANDARCHIVE_KIND = _descriptor.EnumDescriptor(
  name='Kind',
  full_name='TSWP.TextCommandArchive.Kind',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='kKindContained', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKindReplaceText', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKindPaste', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKindParagraphStyle', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKindListStyle', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKindIndentParagraphLevel', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKindDragText', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKindPasteStyle', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKindApplyChangesInRange', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKindInsertCitationField', index=9, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKindInsertBibliographyEntry', index=10, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKindFormatCitationFields', index=11, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKindInsertTOCSmartField', index=12, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKindInsertDateTimeField', index=13, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKindUpdateDateTimeField', index=14, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKindSetParagraphFirstTopicNumber', index=15, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKindCharacterStyle', index=16, number=17,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKindRevertStyles', index=17, number=18,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKindSetParagraphBidi', index=18, number=19,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=566,
  serialized_end=1075,
)
_sym_db.RegisterEnumDescriptor(_TEXTCOMMANDARCHIVE_KIND)

_STORAGEACTIONCOMMANDARCHIVE_KIND = _descriptor.EnumDescriptor(
  name='Kind',
  full_name='TSWP.StorageActionCommandArchive.Kind',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='kKindContained', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKindReplaceText', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKindPaste', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKindParagraphStyle', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKindListStyle', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKindIndentParagraphLevel', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKindDragText', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKindPasteStyle', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKindApplyChangesInRange', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKindInsertCitationField', index=9, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKindInsertBibliographyEntry', index=10, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKindFormatCitationFields', index=11, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKindInsertTOCSmartField', index=12, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKindInsertDateTimeField', index=13, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKindUpdateDateTimeField', index=14, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKindSetParagraphFirstTopicNumber', index=15, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKindCharacterStyle', index=16, number=17,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKindRevertStyles', index=17, number=18,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKindSetParagraphBidi', index=18, number=19,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKindFormatText', index=19, number=20,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKindInsertAttachment', index=20, number=21,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKindCreateHyperlink', index=21, number=22,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKindModifyHyperlink', index=22, number=23,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKindRemoveHyperlink', index=23, number=24,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKindApplyHighlightText', index=24, number=25,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKindPropagateStyleChanges', index=25, number=26,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKindMovedAnchoredDrawableInline', index=26, number=27,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKindMoveDrawablesAttached', index=27, number=28,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKindMoveMoveDrawablesFloating', index=28, number=29,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKindMoveInlineDrawableAnchored', index=29, number=30,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKindAnchorAttachment', index=30, number=31,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKindBookmark', index=31, number=32,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKindReplaceSection', index=32, number=33,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKindApplyPencilAnnotation', index=33, number=34,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKindCreateRuby', index=34, number=35,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKindModifyRuby', index=35, number=36,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKindRemoveRuby', index=36, number=37,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKindTateChuYoko', index=37, number=38,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kKindDropCapStyle', index=38, number=39,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1556,
  serialized_end=2606,
)
_sym_db.RegisterEnumDescriptor(_STORAGEACTIONCOMMANDARCHIVE_KIND)

_UPDATEFLOWINFOCOMMANDARCHIVE_MODE = _descriptor.EnumDescriptor(
  name='Mode',
  full_name='TSWP.UpdateFlowInfoCommandArchive.Mode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='kModeRearrange', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kModeAdd', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kModeRemove', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='kModeCompensate', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8912,
  serialized_end=8990,
)
_sym_db.RegisterEnumDescriptor(_UPDATEFLOWINFOCOMMANDARCHIVE_MODE)


_DUMMYCOMMANDARCHIVE = _descriptor.Descriptor(
  name='DummyCommandArchive',
  full_name='TSWP.DummyCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='foo', full_name='TSWP.DummyCommandArchive.foo', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=181,
  serialized_end=215,
)


_TEXTCOMMANDARCHIVE = _descriptor.Descriptor(
  name='TextCommandArchive',
  full_name='TSWP.TextCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSWP.TextCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='storage', full_name='TSWP.TextCommandArchive.storage', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_transaction', full_name='TSWP.TextCommandArchive.undo_transaction', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='restore_range_location', full_name='TSWP.TextCommandArchive.restore_range_location', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='restore_range_length', full_name='TSWP.TextCommandArchive.restore_range_length', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='redo_restore_range_location', full_name='TSWP.TextCommandArchive.redo_restore_range_location', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='redo_restore_range_length', full_name='TSWP.TextCommandArchive.redo_restore_range_length', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='text_command_flags', full_name='TSWP.TextCommandArchive.text_command_flags', index=7,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='kind', full_name='TSWP.TextCommandArchive.kind', index=8,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TEXTCOMMANDARCHIVE_KIND,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=218,
  serialized_end=1075,
)


_STORAGEACTIONCOMMANDARCHIVE = _descriptor.Descriptor(
  name='StorageActionCommandArchive',
  full_name='TSWP.StorageActionCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSWP.StorageActionCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='storage', full_name='TSWP.StorageActionCommandArchive.storage', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_transaction', full_name='TSWP.StorageActionCommandArchive.undo_transaction', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='text_command_flags', full_name='TSWP.StorageActionCommandArchive.text_command_flags', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='kind', full_name='TSWP.StorageActionCommandArchive.kind', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_format_keys', full_name='TSWP.StorageActionCommandArchive.custom_format_keys', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_forward_inverse_command', full_name='TSWP.StorageActionCommandArchive.is_forward_inverse_command', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='coalesceable', full_name='TSWP.StorageActionCommandArchive.coalesceable', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='coalescing_text', full_name='TSWP.StorageActionCommandArchive.coalescing_text', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='should_migrate_styles', full_name='TSWP.StorageActionCommandArchive.should_migrate_styles', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='changed_data_reference_record', full_name='TSWP.StorageActionCommandArchive.changed_data_reference_record', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='coalescing_property', full_name='TSWP.StorageActionCommandArchive.coalescing_property', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _STORAGEACTIONCOMMANDARCHIVE_KIND,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1078,
  serialized_end=2606,
)


_SETCOLUMNSTYLECOMMANDARCHIVE = _descriptor.Descriptor(
  name='SetColumnStyleCommandArchive',
  full_name='TSWP.SetColumnStyleCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSWP.SetColumnStyleCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='storage', full_name='TSWP.SetColumnStyleCommandArchive.storage', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_transaction', full_name='TSWP.SetColumnStyleCommandArchive.undo_transaction', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2609,
  serialized_end=2757,
)


_REPLACEALLUSESOFSTYLECOMMANDARCHIVE = _descriptor.Descriptor(
  name='ReplaceAllUsesOfStyleCommandArchive',
  full_name='TSWP.ReplaceAllUsesOfStyleCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSWP.ReplaceAllUsesOfStyleCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='storage', full_name='TSWP.ReplaceAllUsesOfStyleCommandArchive.storage', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_transaction', full_name='TSWP.ReplaceAllUsesOfStyleCommandArchive.undo_transaction', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2760,
  serialized_end=2915,
)


_INSERTCOLUMNSCOMMANDARCHIVE = _descriptor.Descriptor(
  name='InsertColumnsCommandArchive',
  full_name='TSWP.InsertColumnsCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSWP.InsertColumnsCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='storage', full_name='TSWP.InsertColumnsCommandArchive.storage', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='column_index', full_name='TSWP.InsertColumnsCommandArchive.column_index', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='column_count', full_name='TSWP.InsertColumnsCommandArchive.column_count', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_transaction', full_name='TSWP.InsertColumnsCommandArchive.undo_transaction', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2918,
  serialized_end=3109,
)


_INSERTROWSCOMMANDARCHIVE = _descriptor.Descriptor(
  name='InsertRowsCommandArchive',
  full_name='TSWP.InsertRowsCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSWP.InsertRowsCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='storage', full_name='TSWP.InsertRowsCommandArchive.storage', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='row_index', full_name='TSWP.InsertRowsCommandArchive.row_index', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='row_count', full_name='TSWP.InsertRowsCommandArchive.row_count', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_transaction', full_name='TSWP.InsertRowsCommandArchive.undo_transaction', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3112,
  serialized_end=3294,
)


_REMOVECOLUMNSCOMMANDARCHIVE = _descriptor.Descriptor(
  name='RemoveColumnsCommandArchive',
  full_name='TSWP.RemoveColumnsCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSWP.RemoveColumnsCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='storage', full_name='TSWP.RemoveColumnsCommandArchive.storage', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='column_index', full_name='TSWP.RemoveColumnsCommandArchive.column_index', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='column_count', full_name='TSWP.RemoveColumnsCommandArchive.column_count', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_transaction', full_name='TSWP.RemoveColumnsCommandArchive.undo_transaction', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3297,
  serialized_end=3488,
)


_REMOVEROWSCOMMANDARCHIVE = _descriptor.Descriptor(
  name='RemoveRowsCommandArchive',
  full_name='TSWP.RemoveRowsCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSWP.RemoveRowsCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='storage', full_name='TSWP.RemoveRowsCommandArchive.storage', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='row_index', full_name='TSWP.RemoveRowsCommandArchive.row_index', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='row_count', full_name='TSWP.RemoveRowsCommandArchive.row_count', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_transaction', full_name='TSWP.RemoveRowsCommandArchive.undo_transaction', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3491,
  serialized_end=3673,
)


_MERGECELLSCOMMANDARCHIVE = _descriptor.Descriptor(
  name='MergeCellsCommandArchive',
  full_name='TSWP.MergeCellsCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSWP.MergeCellsCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='storage', full_name='TSWP.MergeCellsCommandArchive.storage', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='row', full_name='TSWP.MergeCellsCommandArchive.row', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='column', full_name='TSWP.MergeCellsCommandArchive.column', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='row_count', full_name='TSWP.MergeCellsCommandArchive.row_count', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='column_count', full_name='TSWP.MergeCellsCommandArchive.column_count', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_transaction', full_name='TSWP.MergeCellsCommandArchive.undo_transaction', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3676,
  serialized_end=3890,
)


_APPLYPLACEHOLDERTEXTCOMMANDARCHIVE = _descriptor.Descriptor(
  name='ApplyPlaceholderTextCommandArchive',
  full_name='TSWP.ApplyPlaceholderTextCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSWP.ApplyPlaceholderTextCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='storage', full_name='TSWP.ApplyPlaceholderTextCommandArchive.storage', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='selection_range_location', full_name='TSWP.ApplyPlaceholderTextCommandArchive.selection_range_location', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='selection_range_length', full_name='TSWP.ApplyPlaceholderTextCommandArchive.selection_range_length', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_transaction', full_name='TSWP.ApplyPlaceholderTextCommandArchive.undo_transaction', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='script_tag', full_name='TSWP.ApplyPlaceholderTextCommandArchive.script_tag', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3893,
  serialized_end=4133,
)


_UPDATEDATETIMEFIELDCOMMANDARCHIVE = _descriptor.Descriptor(
  name='UpdateDateTimeFieldCommandArchive',
  full_name='TSWP.UpdateDateTimeFieldCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSWP.UpdateDateTimeFieldCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date_time_field', full_name='TSWP.UpdateDateTimeFieldCommandArchive.date_time_field', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date', full_name='TSWP.UpdateDateTimeFieldCommandArchive.date', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date_style', full_name='TSWP.UpdateDateTimeFieldCommandArchive.date_style', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_style', full_name='TSWP.UpdateDateTimeFieldCommandArchive.time_style', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4136,
  serialized_end=4430,
)


_APPLYRUBYTEXTCOMMANDARCHIVE = _descriptor.Descriptor(
  name='ApplyRubyTextCommandArchive',
  full_name='TSWP.ApplyRubyTextCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSWP.ApplyRubyTextCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='storage', full_name='TSWP.ApplyRubyTextCommandArchive.storage', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='selection_range_location', full_name='TSWP.ApplyRubyTextCommandArchive.selection_range_location', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='selection_range_length', full_name='TSWP.ApplyRubyTextCommandArchive.selection_range_length', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ruby_text', full_name='TSWP.ApplyRubyTextCommandArchive.ruby_text', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_transaction', full_name='TSWP.ApplyRubyTextCommandArchive.undo_transaction', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4433,
  serialized_end=4665,
)


_MODIFYRUBYTEXTCOMMANDARCHIVE = _descriptor.Descriptor(
  name='ModifyRubyTextCommandArchive',
  full_name='TSWP.ModifyRubyTextCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSWP.ModifyRubyTextCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ruby_field', full_name='TSWP.ModifyRubyTextCommandArchive.ruby_field', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ruby_text', full_name='TSWP.ModifyRubyTextCommandArchive.ruby_text', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='base_text', full_name='TSWP.ModifyRubyTextCommandArchive.base_text', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_transaction', full_name='TSWP.ModifyRubyTextCommandArchive.undo_transaction', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4668,
  serialized_end=4857,
)


_MODIFYTOCSETTINGSBASECOMMANDARCHIVE = _descriptor.Descriptor(
  name='ModifyTOCSettingsBaseCommandArchive',
  full_name='TSWP.ModifyTOCSettingsBaseCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSWP.ModifyTOCSettingsBaseCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_toc_settings', full_name='TSWP.ModifyTOCSettingsBaseCommandArchive.old_toc_settings', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_toc_settings', full_name='TSWP.ModifyTOCSettingsBaseCommandArchive.new_toc_settings', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4860,
  serialized_end=5017,
)


_MODIFYTOCSETTINGSFORTOCINFOCOMMANDARCHIVE = _descriptor.Descriptor(
  name='ModifyTOCSettingsForTOCInfoCommandArchive',
  full_name='TSWP.ModifyTOCSettingsForTOCInfoCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSWP.ModifyTOCSettingsForTOCInfoCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='toc_info_uuid_path', full_name='TSWP.ModifyTOCSettingsForTOCInfoCommandArchive.toc_info_uuid_path', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5020,
  serialized_end=5164,
)


_MODIFYTOCSETTINGSPRESETFORTHEMECOMMANDARCHIVE = _descriptor.Descriptor(
  name='ModifyTOCSettingsPresetForThemeCommandArchive',
  full_name='TSWP.ModifyTOCSettingsPresetForThemeCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSWP.ModifyTOCSettingsPresetForThemeCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='theme', full_name='TSWP.ModifyTOCSettingsPresetForThemeCommandArchive.theme', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preset_index', full_name='TSWP.ModifyTOCSettingsPresetForThemeCommandArchive.preset_index', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5167,
  serialized_end=5325,
)


_ANCHORATTACHMENTCOMMANDARCHIVE = _descriptor.Descriptor(
  name='AnchorAttachmentCommandArchive',
  full_name='TSWP.AnchorAttachmentCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSWP.AnchorAttachmentCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attachment', full_name='TSWP.AnchorAttachmentCommandArchive.attachment', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='h_offset_type', full_name='TSWP.AnchorAttachmentCommandArchive.h_offset_type', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='h_offset', full_name='TSWP.AnchorAttachmentCommandArchive.h_offset', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='v_offset_type', full_name='TSWP.AnchorAttachmentCommandArchive.v_offset_type', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='v_offset', full_name='TSWP.AnchorAttachmentCommandArchive.v_offset', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_html_wrap', full_name='TSWP.AnchorAttachmentCommandArchive.is_html_wrap', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_h_offset_type', full_name='TSWP.AnchorAttachmentCommandArchive.undo_h_offset_type', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_h_offset', full_name='TSWP.AnchorAttachmentCommandArchive.undo_h_offset', index=8,
      number=9, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_v_offset_type', full_name='TSWP.AnchorAttachmentCommandArchive.undo_v_offset_type', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_v_offset', full_name='TSWP.AnchorAttachmentCommandArchive.undo_v_offset', index=10,
      number=11, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_is_html_wrap', full_name='TSWP.AnchorAttachmentCommandArchive.undo_is_html_wrap', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5328,
  serialized_end=5679,
)


_TEXTAPPLYTHEMECOMMANDARCHIVE = _descriptor.Descriptor(
  name='TextApplyThemeCommandArchive',
  full_name='TSWP.TextApplyThemeCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSWP.TextApplyThemeCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='storage', full_name='TSWP.TextApplyThemeCommandArchive.storage', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_transaction', full_name='TSWP.TextApplyThemeCommandArchive.undo_transaction', index=2,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5682,
  serialized_end=5845,
)


_MOVECOLUMNSCOMMANDARCHIVE = _descriptor.Descriptor(
  name='MoveColumnsCommandArchive',
  full_name='TSWP.MoveColumnsCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSWP.MoveColumnsCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='storage', full_name='TSWP.MoveColumnsCommandArchive.storage', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='src_index', full_name='TSWP.MoveColumnsCommandArchive.src_index', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dst_index', full_name='TSWP.MoveColumnsCommandArchive.dst_index', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='count', full_name='TSWP.MoveColumnsCommandArchive.count', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_transaction', full_name='TSWP.MoveColumnsCommandArchive.undo_transaction', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5848,
  serialized_end=6046,
)


_MOVEROWSCOMMANDARCHIVE = _descriptor.Descriptor(
  name='MoveRowsCommandArchive',
  full_name='TSWP.MoveRowsCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSWP.MoveRowsCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='storage', full_name='TSWP.MoveRowsCommandArchive.storage', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='src_index', full_name='TSWP.MoveRowsCommandArchive.src_index', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dst_index', full_name='TSWP.MoveRowsCommandArchive.dst_index', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='count', full_name='TSWP.MoveRowsCommandArchive.count', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_transaction', full_name='TSWP.MoveRowsCommandArchive.undo_transaction', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6049,
  serialized_end=6244,
)


_SHAPEAPPLYPRESETCOMMANDARCHIVE = _descriptor.Descriptor(
  name='ShapeApplyPresetCommandArchive',
  full_name='TSWP.ShapeApplyPresetCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSWP.ShapeApplyPresetCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_style', full_name='TSWP.ShapeApplyPresetCommandArchive.undo_style', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6246,
  serialized_end=6365,
)


_STYLEBASECOMMANDARCHIVE = _descriptor.Descriptor(
  name='StyleBaseCommandArchive',
  full_name='TSWP.StyleBaseCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSWP.StyleBaseCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='theme', full_name='TSWP.StyleBaseCommandArchive.theme', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='style', full_name='TSWP.StyleBaseCommandArchive.style', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6367,
  serialized_end=6490,
)


_STYLECREATECOMMANDARCHIVE = _descriptor.Descriptor(
  name='StyleCreateCommandArchive',
  full_name='TSWP.StyleCreateCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSWP.StyleCreateCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preset_index', full_name='TSWP.StyleCreateCommandArchive.preset_index', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6492,
  serialized_end=6587,
)


_STYLERENAMECOMMANDARCHIVE = _descriptor.Descriptor(
  name='StyleRenameCommandArchive',
  full_name='TSWP.StyleRenameCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSWP.StyleRenameCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='updated_name', full_name='TSWP.StyleRenameCommandArchive.updated_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_name', full_name='TSWP.StyleRenameCommandArchive.old_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6589,
  serialized_end=6702,
)


_STYLEUPDATECOMMANDARCHIVE = _descriptor.Descriptor(
  name='StyleUpdateCommandArchive',
  full_name='TSWP.StyleUpdateCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSWP.StyleUpdateCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='original_style', full_name='TSWP.StyleUpdateCommandArchive.original_style', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='updated_style', full_name='TSWP.StyleUpdateCommandArchive.updated_style', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6705,
  serialized_end=6857,
)


_STYLEDELETECOMMANDARCHIVE = _descriptor.Descriptor(
  name='StyleDeleteCommandArchive',
  full_name='TSWP.StyleDeleteCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSWP.StyleDeleteCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_preset_index', full_name='TSWP.StyleDeleteCommandArchive.old_preset_index', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6859,
  serialized_end=6958,
)


_STYLEREORDERCOMMANDARCHIVE = _descriptor.Descriptor(
  name='StyleReorderCommandArchive',
  full_name='TSWP.StyleReorderCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSWP.StyleReorderCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_preset_index', full_name='TSWP.StyleReorderCommandArchive.old_preset_index', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_preset_index', full_name='TSWP.StyleReorderCommandArchive.new_preset_index', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6960,
  serialized_end=7086,
)


_STYLEUPDATEPROPERTYMAPCOMMANDARCHIVE = _descriptor.Descriptor(
  name='StyleUpdatePropertyMapCommandArchive',
  full_name='TSWP.StyleUpdatePropertyMapCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSWP.StyleUpdatePropertyMapCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7088,
  serialized_end=7184,
)


_SHAPESTYLESETVALUECOMMANDARCHIVE = _descriptor.Descriptor(
  name='ShapeStyleSetValueCommandArchive',
  full_name='TSWP.ShapeStyleSetValueCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSWP.ShapeStyleSetValueCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='change', full_name='TSWP.ShapeStyleSetValueCommandArchive.change', index=1,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7187,
  serialized_end=7332,
)


_SELECTIONTRANSFORMERARCHIVE = _descriptor.Descriptor(
  name='SelectionTransformerArchive',
  full_name='TSWP.SelectionTransformerArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='storage_uuid_path', full_name='TSWP.SelectionTransformerArchive.storage_uuid_path', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='selection', full_name='TSWP.SelectionTransformerArchive.selection', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transformed_to_noop', full_name='TSWP.SelectionTransformerArchive.transformed_to_noop', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7335,
  serialized_end=7470,
)


_PENCILANNOTATIONSELECTIONTRANSFORMERARCHIVE = _descriptor.Descriptor(
  name='PencilAnnotationSelectionTransformerArchive',
  full_name='TSWP.PencilAnnotationSelectionTransformerArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='storage_uuid_path', full_name='TSWP.PencilAnnotationSelectionTransformerArchive.storage_uuid_path', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='text_pencil_annotation_uuid', full_name='TSWP.PencilAnnotationSelectionTransformerArchive.text_pencil_annotation_uuid', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7472,
  serialized_end=7596,
)


_SHAPESELECTIONTRANSFORMERARCHIVE = _descriptor.Descriptor(
  name='ShapeSelectionTransformerArchive',
  full_name='TSWP.ShapeSelectionTransformerArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSWP.ShapeSelectionTransformerArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='storage_uuid_path', full_name='TSWP.ShapeSelectionTransformerArchive.storage_uuid_path', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7599,
  serialized_end=7729,
)


_SHAPECONTENTDESCRIPTION = _descriptor.Descriptor(
  name='ShapeContentDescription',
  full_name='TSWP.ShapeContentDescription',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSWP.ShapeContentDescription.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='text_range_location', full_name='TSWP.ShapeContentDescription.text_range_location', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='text_range_length', full_name='TSWP.ShapeContentDescription.text_range_length', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7732,
  serialized_end=7861,
)


_OBJECTPROPERTYARCHIVE = _descriptor.Descriptor(
  name='ObjectPropertyArchive',
  full_name='TSWP.ObjectPropertyArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='TSWP.ObjectPropertyArchive.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='TSWP.ObjectPropertyArchive.type', index=1,
      number=2, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bool_value', full_name='TSWP.ObjectPropertyArchive.bool_value', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='float_value', full_name='TSWP.ObjectPropertyArchive.float_value', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='integer_value', full_name='TSWP.ObjectPropertyArchive.integer_value', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='string_value', full_name='TSWP.ObjectPropertyArchive.string_value', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id_path_value', full_name='TSWP.ObjectPropertyArchive.id_path_value', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fill_value', full_name='TSWP.ObjectPropertyArchive.fill_value', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='color_value', full_name='TSWP.ObjectPropertyArchive.color_value', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shadow_value', full_name='TSWP.ObjectPropertyArchive.shadow_value', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7864,
  serialized_end=8178,
)


_SETOBJECTPROPERTIESCOMMANDARCHIVE = _descriptor.Descriptor(
  name='SetObjectPropertiesCommandArchive',
  full_name='TSWP.SetObjectPropertiesCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSWP.SetObjectPropertiesCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='object_uuid_path', full_name='TSWP.SetObjectPropertiesCommandArchive.object_uuid_path', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='properties', full_name='TSWP.SetObjectPropertiesCommandArchive.properties', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='action_string', full_name='TSWP.SetObjectPropertiesCommandArchive.action_string', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_properties', full_name='TSWP.SetObjectPropertiesCommandArchive.old_properties', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8181,
  serialized_end=8418,
)


_UPDATEFLOWINFOCOMMANDARCHIVE = _descriptor.Descriptor(
  name='UpdateFlowInfoCommandArchive',
  full_name='TSWP.UpdateFlowInfoCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSWP.UpdateFlowInfoCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='command_mode', full_name='TSWP.UpdateFlowInfoCommandArchive.command_mode', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flow_info_uuid_path', full_name='TSWP.UpdateFlowInfoCommandArchive.flow_info_uuid_path', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='text_box_id_path_to_add_or_remove', full_name='TSWP.UpdateFlowInfoCommandArchive.text_box_id_path_to_add_or_remove', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='text_box_id_paths_at_start', full_name='TSWP.UpdateFlowInfoCommandArchive.text_box_id_paths_at_start', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='suggested_text_box_id_paths_at_end', full_name='TSWP.UpdateFlowInfoCommandArchive.suggested_text_box_id_paths_at_end', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_text_boxes_to_restore', full_name='TSWP.UpdateFlowInfoCommandArchive.undo_text_boxes_to_restore', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_added_shape_info', full_name='TSWP.UpdateFlowInfoCommandArchive.undo_added_shape_info', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_removed_shape_info', full_name='TSWP.UpdateFlowInfoCommandArchive.undo_removed_shape_info', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _UPDATEFLOWINFOCOMMANDARCHIVE_MODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8421,
  serialized_end=8990,
)


_ADDFLOWINFOCOMMANDARCHIVE = _descriptor.Descriptor(
  name='AddFlowInfoCommandArchive',
  full_name='TSWP.AddFlowInfoCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSWP.AddFlowInfoCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flow_info_to_add', full_name='TSWP.AddFlowInfoCommandArchive.flow_info_to_add', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flow_info_archive', full_name='TSWP.AddFlowInfoCommandArchive.flow_info_archive', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_user_interface_identifier_to_restore', full_name='TSWP.AddFlowInfoCommandArchive.undo_user_interface_identifier_to_restore', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_next_user_interface_identifier_to_restore', full_name='TSWP.AddFlowInfoCommandArchive.undo_next_user_interface_identifier_to_restore', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='working_undo_object', full_name='TSWP.AddFlowInfoCommandArchive.working_undo_object', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8993,
  serialized_end=9293,
)


_REMOVEFLOWINFOCOMMANDARCHIVE = _descriptor.Descriptor(
  name='RemoveFlowInfoCommandArchive',
  full_name='TSWP.RemoveFlowInfoCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSWP.RemoveFlowInfoCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flow_info_uuid_path', full_name='TSWP.RemoveFlowInfoCommandArchive.flow_info_uuid_path', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_object', full_name='TSWP.RemoveFlowInfoCommandArchive.undo_object', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_user_interface_identifier_to_restore', full_name='TSWP.RemoveFlowInfoCommandArchive.undo_user_interface_identifier_to_restore', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_next_user_interface_identifier_to_restore', full_name='TSWP.RemoveFlowInfoCommandArchive.undo_next_user_interface_identifier_to_restore', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9296,
  serialized_end=9550,
)


_TEXTCOMMENTREPLYCOMMANDARCHIVE = _descriptor.Descriptor(
  name='TextCommentReplyCommandArchive',
  full_name='TSWP.TextCommentReplyCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSWP.TextCommentReplyCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='storage_uuid_path', full_name='TSWP.TextCommentReplyCommandArchive.storage_uuid_path', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='annotation_uuid', full_name='TSWP.TextCommentReplyCommandArchive.annotation_uuid', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='forward_comment', full_name='TSWP.TextCommentReplyCommandArchive.forward_comment', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inverse_comment', full_name='TSWP.TextCommentReplyCommandArchive.inverse_comment', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='forward_variant', full_name='TSWP.TextCommentReplyCommandArchive.forward_variant', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inverse_variant', full_name='TSWP.TextCommentReplyCommandArchive.inverse_variant', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9553,
  serialized_end=9876,
)


_CONTAINEDOBJECTSCOMMANDARCHIVE_ADDBEHAVIORARGS = _descriptor.Descriptor(
  name='AddBehaviorArgs',
  full_name='TSWP.ContainedObjectsCommandArchive.AddBehaviorArgs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='args_list', full_name='TSWP.ContainedObjectsCommandArchive.AddBehaviorArgs.args_list', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10411,
  serialized_end=10472,
)

_CONTAINEDOBJECTSCOMMANDARCHIVE_REMOVEBEHAVIORARGS = _descriptor.Descriptor(
  name='RemoveBehaviorArgs',
  full_name='TSWP.ContainedObjectsCommandArchive.RemoveBehaviorArgs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='args_list', full_name='TSWP.ContainedObjectsCommandArchive.RemoveBehaviorArgs.args_list', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10474,
  serialized_end=10541,
)

_CONTAINEDOBJECTSCOMMANDARCHIVE_REARRANGEBEHAVIORARGS = _descriptor.Descriptor(
  name='RearrangeBehaviorArgs',
  full_name='TSWP.ContainedObjectsCommandArchive.RearrangeBehaviorArgs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='args_list', full_name='TSWP.ContainedObjectsCommandArchive.RearrangeBehaviorArgs.args_list', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10543,
  serialized_end=10616,
)

_CONTAINEDOBJECTSCOMMANDARCHIVE = _descriptor.Descriptor(
  name='ContainedObjectsCommandArchive',
  full_name='TSWP.ContainedObjectsCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSWP.ContainedObjectsCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='target', full_name='TSWP.ContainedObjectsCommandArchive.target', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='objects', full_name='TSWP.ContainedObjectsCommandArchive.objects', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_object_for_commit', full_name='TSWP.ContainedObjectsCommandArchive.undo_object_for_commit', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_object_for_make_inverse', full_name='TSWP.ContainedObjectsCommandArchive.undo_object_for_make_inverse', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='add_behavior_args', full_name='TSWP.ContainedObjectsCommandArchive.add_behavior_args', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remove_behavior_args', full_name='TSWP.ContainedObjectsCommandArchive.remove_behavior_args', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rearrange_behavior_args', full_name='TSWP.ContainedObjectsCommandArchive.rearrange_behavior_args', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='container_name', full_name='TSWP.ContainedObjectsCommandArchive.container_name', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CONTAINEDOBJECTSCOMMANDARCHIVE_ADDBEHAVIORARGS, _CONTAINEDOBJECTSCOMMANDARCHIVE_REMOVEBEHAVIORARGS, _CONTAINEDOBJECTSCOMMANDARCHIVE_REARRANGEBEHAVIORARGS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='undo_object', full_name='TSWP.ContainedObjectsCommandArchive.undo_object',
      index=0, containing_type=None, fields=[]),
    _descriptor.OneofDescriptor(
      name='behavior', full_name='TSWP.ContainedObjectsCommandArchive.behavior',
      index=1, containing_type=None, fields=[]),
  ],
  serialized_start=9879,
  serialized_end=10643,
)


_EQUATIONINFOGEOMETRYCOMMANDARCHIVE = _descriptor.Descriptor(
  name='EquationInfoGeometryCommandArchive',
  full_name='TSWP.EquationInfoGeometryCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSWP.EquationInfoGeometryCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10645,
  serialized_end=10734,
)

_TEXTCOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_TEXTCOMMANDARCHIVE.fields_by_name['storage'].message_type = TSPMessages__pb2._REFERENCE
_TEXTCOMMANDARCHIVE.fields_by_name['undo_transaction'].message_type = TSWPArchives__pb2._UNDOTRANSACTION
_TEXTCOMMANDARCHIVE.fields_by_name['kind'].enum_type = _TEXTCOMMANDARCHIVE_KIND
_TEXTCOMMANDARCHIVE_KIND.containing_type = _TEXTCOMMANDARCHIVE
_STORAGEACTIONCOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_STORAGEACTIONCOMMANDARCHIVE.fields_by_name['storage'].message_type = TSPMessages__pb2._UUIDPATH
_STORAGEACTIONCOMMANDARCHIVE.fields_by_name['undo_transaction'].message_type = TSWPArchives__pb2._UNDOTRANSACTION
_STORAGEACTIONCOMMANDARCHIVE.fields_by_name['kind'].enum_type = _STORAGEACTIONCOMMANDARCHIVE_KIND
_STORAGEACTIONCOMMANDARCHIVE.fields_by_name['custom_format_keys'].message_type = TSPMessages__pb2._UUID
_STORAGEACTIONCOMMANDARCHIVE.fields_by_name['changed_data_reference_record'].message_type = TSKArchives__pb2._DATAREFERENCERECORD
_STORAGEACTIONCOMMANDARCHIVE_KIND.containing_type = _STORAGEACTIONCOMMANDARCHIVE
_SETCOLUMNSTYLECOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_SETCOLUMNSTYLECOMMANDARCHIVE.fields_by_name['storage'].message_type = TSPMessages__pb2._REFERENCE
_SETCOLUMNSTYLECOMMANDARCHIVE.fields_by_name['undo_transaction'].message_type = TSWPArchives__pb2._UNDOTRANSACTION
_REPLACEALLUSESOFSTYLECOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_REPLACEALLUSESOFSTYLECOMMANDARCHIVE.fields_by_name['storage'].message_type = TSPMessages__pb2._REFERENCE
_REPLACEALLUSESOFSTYLECOMMANDARCHIVE.fields_by_name['undo_transaction'].message_type = TSWPArchives__pb2._UNDOTRANSACTION
_INSERTCOLUMNSCOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_INSERTCOLUMNSCOMMANDARCHIVE.fields_by_name['storage'].message_type = TSPMessages__pb2._REFERENCE
_INSERTCOLUMNSCOMMANDARCHIVE.fields_by_name['undo_transaction'].message_type = TSWPArchives__pb2._UNDOTRANSACTION
_INSERTROWSCOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_INSERTROWSCOMMANDARCHIVE.fields_by_name['storage'].message_type = TSPMessages__pb2._REFERENCE
_INSERTROWSCOMMANDARCHIVE.fields_by_name['undo_transaction'].message_type = TSWPArchives__pb2._UNDOTRANSACTION
_REMOVECOLUMNSCOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_REMOVECOLUMNSCOMMANDARCHIVE.fields_by_name['storage'].message_type = TSPMessages__pb2._REFERENCE
_REMOVECOLUMNSCOMMANDARCHIVE.fields_by_name['undo_transaction'].message_type = TSWPArchives__pb2._UNDOTRANSACTION
_REMOVEROWSCOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_REMOVEROWSCOMMANDARCHIVE.fields_by_name['storage'].message_type = TSPMessages__pb2._REFERENCE
_REMOVEROWSCOMMANDARCHIVE.fields_by_name['undo_transaction'].message_type = TSWPArchives__pb2._UNDOTRANSACTION
_MERGECELLSCOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_MERGECELLSCOMMANDARCHIVE.fields_by_name['storage'].message_type = TSPMessages__pb2._REFERENCE
_MERGECELLSCOMMANDARCHIVE.fields_by_name['undo_transaction'].message_type = TSWPArchives__pb2._UNDOTRANSACTION
_APPLYPLACEHOLDERTEXTCOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_APPLYPLACEHOLDERTEXTCOMMANDARCHIVE.fields_by_name['storage'].message_type = TSPMessages__pb2._REFERENCE
_APPLYPLACEHOLDERTEXTCOMMANDARCHIVE.fields_by_name['undo_transaction'].message_type = TSWPArchives__pb2._UNDOTRANSACTION
_UPDATEDATETIMEFIELDCOMMANDARCHIVE.fields_by_name['super'].message_type = _TEXTCOMMANDARCHIVE
_UPDATEDATETIMEFIELDCOMMANDARCHIVE.fields_by_name['date_time_field'].message_type = TSPMessages__pb2._REFERENCE
_UPDATEDATETIMEFIELDCOMMANDARCHIVE.fields_by_name['date'].message_type = TSPMessages__pb2._DATE
_UPDATEDATETIMEFIELDCOMMANDARCHIVE.fields_by_name['date_style'].enum_type = TSWPArchives__pb2._DATETIMESMARTFIELDARCHIVE_DATETIMEFORMATTERSTYLE
_UPDATEDATETIMEFIELDCOMMANDARCHIVE.fields_by_name['time_style'].enum_type = TSWPArchives__pb2._DATETIMESMARTFIELDARCHIVE_DATETIMEFORMATTERSTYLE
_APPLYRUBYTEXTCOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_APPLYRUBYTEXTCOMMANDARCHIVE.fields_by_name['storage'].message_type = TSPMessages__pb2._REFERENCE
_APPLYRUBYTEXTCOMMANDARCHIVE.fields_by_name['undo_transaction'].message_type = TSWPArchives__pb2._UNDOTRANSACTION
_MODIFYRUBYTEXTCOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_MODIFYRUBYTEXTCOMMANDARCHIVE.fields_by_name['ruby_field'].message_type = TSPMessages__pb2._REFERENCE
_MODIFYRUBYTEXTCOMMANDARCHIVE.fields_by_name['undo_transaction'].message_type = TSWPArchives__pb2._UNDOTRANSACTION
_MODIFYTOCSETTINGSBASECOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_MODIFYTOCSETTINGSBASECOMMANDARCHIVE.fields_by_name['old_toc_settings'].message_type = TSPMessages__pb2._REFERENCE
_MODIFYTOCSETTINGSBASECOMMANDARCHIVE.fields_by_name['new_toc_settings'].message_type = TSPMessages__pb2._REFERENCE
_MODIFYTOCSETTINGSFORTOCINFOCOMMANDARCHIVE.fields_by_name['super'].message_type = _MODIFYTOCSETTINGSBASECOMMANDARCHIVE
_MODIFYTOCSETTINGSFORTOCINFOCOMMANDARCHIVE.fields_by_name['toc_info_uuid_path'].message_type = TSPMessages__pb2._UUIDPATH
_MODIFYTOCSETTINGSPRESETFORTHEMECOMMANDARCHIVE.fields_by_name['super'].message_type = _MODIFYTOCSETTINGSBASECOMMANDARCHIVE
_MODIFYTOCSETTINGSPRESETFORTHEMECOMMANDARCHIVE.fields_by_name['theme'].message_type = TSPMessages__pb2._REFERENCE
_ANCHORATTACHMENTCOMMANDARCHIVE.fields_by_name['super'].message_type = _STORAGEACTIONCOMMANDARCHIVE
_ANCHORATTACHMENTCOMMANDARCHIVE.fields_by_name['attachment'].message_type = TSPMessages__pb2._REFERENCE
_TEXTAPPLYTHEMECOMMANDARCHIVE.fields_by_name['super'].message_type = TSSArchives__pb2._APPLYTHEMECHILDCOMMANDARCHIVE
_TEXTAPPLYTHEMECOMMANDARCHIVE.fields_by_name['storage'].message_type = TSPMessages__pb2._REFERENCE
_TEXTAPPLYTHEMECOMMANDARCHIVE.fields_by_name['undo_transaction'].message_type = TSWPArchives__pb2._UNDOTRANSACTION
_MOVECOLUMNSCOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_MOVECOLUMNSCOMMANDARCHIVE.fields_by_name['storage'].message_type = TSPMessages__pb2._REFERENCE
_MOVECOLUMNSCOMMANDARCHIVE.fields_by_name['undo_transaction'].message_type = TSWPArchives__pb2._UNDOTRANSACTION
_MOVEROWSCOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_MOVEROWSCOMMANDARCHIVE.fields_by_name['storage'].message_type = TSPMessages__pb2._REFERENCE
_MOVEROWSCOMMANDARCHIVE.fields_by_name['undo_transaction'].message_type = TSWPArchives__pb2._UNDOTRANSACTION
_SHAPEAPPLYPRESETCOMMANDARCHIVE.fields_by_name['super'].message_type = TSDCommandArchives__pb2._BASEAPPLYPRESETCOMMANDARCHIVE
_SHAPEAPPLYPRESETCOMMANDARCHIVE.fields_by_name['undo_style'].message_type = TSPMessages__pb2._REFERENCE
_STYLEBASECOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_STYLEBASECOMMANDARCHIVE.fields_by_name['theme'].message_type = TSPMessages__pb2._REFERENCE
_STYLEBASECOMMANDARCHIVE.fields_by_name['style'].message_type = TSPMessages__pb2._REFERENCE
_STYLECREATECOMMANDARCHIVE.fields_by_name['super'].message_type = _STYLEBASECOMMANDARCHIVE
_STYLERENAMECOMMANDARCHIVE.fields_by_name['super'].message_type = _STYLEBASECOMMANDARCHIVE
_STYLEUPDATECOMMANDARCHIVE.fields_by_name['super'].message_type = _STYLEBASECOMMANDARCHIVE
_STYLEUPDATECOMMANDARCHIVE.fields_by_name['original_style'].message_type = TSPMessages__pb2._REFERENCE
_STYLEUPDATECOMMANDARCHIVE.fields_by_name['updated_style'].message_type = TSPMessages__pb2._REFERENCE
_STYLEDELETECOMMANDARCHIVE.fields_by_name['super'].message_type = _STYLEBASECOMMANDARCHIVE
_STYLEREORDERCOMMANDARCHIVE.fields_by_name['super'].message_type = _STYLEBASECOMMANDARCHIVE
_STYLEUPDATEPROPERTYMAPCOMMANDARCHIVE.fields_by_name['super'].message_type = TSSArchives__pb2._STYLEUPDATEPROPERTYMAPCOMMANDARCHIVE
_SHAPESTYLESETVALUECOMMANDARCHIVE.fields_by_name['super'].message_type = TSDCommandArchives__pb2._BASESTYLESETVALUECOMMANDARCHIVE
_SHAPESTYLESETVALUECOMMANDARCHIVE.fields_by_name['change'].message_type = TSWPArchives__sos__pb2._SHAPESTYLEPROPERTYCHANGESETARCHIVE
_SELECTIONTRANSFORMERARCHIVE.fields_by_name['storage_uuid_path'].message_type = TSPMessages__pb2._UUIDPATH
_SELECTIONTRANSFORMERARCHIVE.fields_by_name['selection'].message_type = TSPMessages__pb2._REFERENCE
_PENCILANNOTATIONSELECTIONTRANSFORMERARCHIVE.fields_by_name['storage_uuid_path'].message_type = TSPMessages__pb2._UUIDPATH
_SHAPESELECTIONTRANSFORMERARCHIVE.fields_by_name['super'].message_type = TSDCommandArchives__pb2._SHAPESELECTIONTRANSFORMERARCHIVE
_SHAPESELECTIONTRANSFORMERARCHIVE.fields_by_name['storage_uuid_path'].message_type = TSPMessages__pb2._UUIDPATH
_SHAPECONTENTDESCRIPTION.fields_by_name['super'].message_type = TSDArchives__pb2._DRAWABLECONTENTDESCRIPTION
_OBJECTPROPERTYARCHIVE.fields_by_name['type'].enum_type = _OBJECTPROPERTYTYPE
_OBJECTPROPERTYARCHIVE.fields_by_name['id_path_value'].message_type = TSPMessages__pb2._UUIDPATH
_OBJECTPROPERTYARCHIVE.fields_by_name['fill_value'].message_type = TSDArchives__pb2._FILLARCHIVE
_OBJECTPROPERTYARCHIVE.fields_by_name['color_value'].message_type = TSPMessages__pb2._COLOR
_OBJECTPROPERTYARCHIVE.fields_by_name['shadow_value'].message_type = TSDArchives__pb2._SHADOWARCHIVE
_SETOBJECTPROPERTIESCOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_SETOBJECTPROPERTIESCOMMANDARCHIVE.fields_by_name['object_uuid_path'].message_type = TSPMessages__pb2._UUIDPATH
_SETOBJECTPROPERTIESCOMMANDARCHIVE.fields_by_name['properties'].message_type = _OBJECTPROPERTYARCHIVE
_SETOBJECTPROPERTIESCOMMANDARCHIVE.fields_by_name['old_properties'].message_type = _OBJECTPROPERTYARCHIVE
_UPDATEFLOWINFOCOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_UPDATEFLOWINFOCOMMANDARCHIVE.fields_by_name['command_mode'].enum_type = _UPDATEFLOWINFOCOMMANDARCHIVE_MODE
_UPDATEFLOWINFOCOMMANDARCHIVE.fields_by_name['flow_info_uuid_path'].message_type = TSPMessages__pb2._UUIDPATH
_UPDATEFLOWINFOCOMMANDARCHIVE.fields_by_name['text_box_id_path_to_add_or_remove'].message_type = TSPMessages__pb2._UUIDPATH
_UPDATEFLOWINFOCOMMANDARCHIVE.fields_by_name['text_box_id_paths_at_start'].message_type = TSPMessages__pb2._UUIDPATH
_UPDATEFLOWINFOCOMMANDARCHIVE.fields_by_name['suggested_text_box_id_paths_at_end'].message_type = TSPMessages__pb2._UUIDPATH
_UPDATEFLOWINFOCOMMANDARCHIVE.fields_by_name['undo_text_boxes_to_restore'].message_type = TSPMessages__pb2._REFERENCE
_UPDATEFLOWINFOCOMMANDARCHIVE.fields_by_name['undo_added_shape_info'].message_type = TSPMessages__pb2._REFERENCE
_UPDATEFLOWINFOCOMMANDARCHIVE.fields_by_name['undo_removed_shape_info'].message_type = TSPMessages__pb2._REFERENCE
_UPDATEFLOWINFOCOMMANDARCHIVE_MODE.containing_type = _UPDATEFLOWINFOCOMMANDARCHIVE
_ADDFLOWINFOCOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_ADDFLOWINFOCOMMANDARCHIVE.fields_by_name['flow_info_to_add'].message_type = TSPMessages__pb2._REFERENCE
_ADDFLOWINFOCOMMANDARCHIVE.fields_by_name['flow_info_archive'].message_type = TSPMessages__pb2._REFERENCE
_ADDFLOWINFOCOMMANDARCHIVE.fields_by_name['working_undo_object'].message_type = TSPMessages__pb2._REFERENCE
_REMOVEFLOWINFOCOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_REMOVEFLOWINFOCOMMANDARCHIVE.fields_by_name['flow_info_uuid_path'].message_type = TSPMessages__pb2._UUIDPATH
_REMOVEFLOWINFOCOMMANDARCHIVE.fields_by_name['undo_object'].message_type = TSPMessages__pb2._REFERENCE
_TEXTCOMMENTREPLYCOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_TEXTCOMMENTREPLYCOMMANDARCHIVE.fields_by_name['storage_uuid_path'].message_type = TSPMessages__pb2._UUIDPATH
_TEXTCOMMENTREPLYCOMMANDARCHIVE.fields_by_name['forward_comment'].message_type = TSPMessages__pb2._REFERENCE
_TEXTCOMMENTREPLYCOMMANDARCHIVE.fields_by_name['inverse_comment'].message_type = TSPMessages__pb2._REFERENCE
_TEXTCOMMENTREPLYCOMMANDARCHIVE.fields_by_name['forward_variant'].enum_type = TSDCommandArchives__pb2._COMMENTCOMMANDVARIANT
_TEXTCOMMENTREPLYCOMMANDARCHIVE.fields_by_name['inverse_variant'].enum_type = TSDCommandArchives__pb2._COMMENTCOMMANDVARIANT
_CONTAINEDOBJECTSCOMMANDARCHIVE_ADDBEHAVIORARGS.fields_by_name['args_list'].message_type = TSKArchives__pb2._ADDIDOPERATIONARGS
_CONTAINEDOBJECTSCOMMANDARCHIVE_ADDBEHAVIORARGS.containing_type = _CONTAINEDOBJECTSCOMMANDARCHIVE
_CONTAINEDOBJECTSCOMMANDARCHIVE_REMOVEBEHAVIORARGS.fields_by_name['args_list'].message_type = TSKArchives__pb2._REMOVEIDOPERATIONARGS
_CONTAINEDOBJECTSCOMMANDARCHIVE_REMOVEBEHAVIORARGS.containing_type = _CONTAINEDOBJECTSCOMMANDARCHIVE
_CONTAINEDOBJECTSCOMMANDARCHIVE_REARRANGEBEHAVIORARGS.fields_by_name['args_list'].message_type = TSKArchives__pb2._REARRANGEIDOPERATIONARGS
_CONTAINEDOBJECTSCOMMANDARCHIVE_REARRANGEBEHAVIORARGS.containing_type = _CONTAINEDOBJECTSCOMMANDARCHIVE
_CONTAINEDOBJECTSCOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_CONTAINEDOBJECTSCOMMANDARCHIVE.fields_by_name['target'].message_type = TSPMessages__pb2._REFERENCE
_CONTAINEDOBJECTSCOMMANDARCHIVE.fields_by_name['objects'].message_type = TSPMessages__pb2._REFERENCE
_CONTAINEDOBJECTSCOMMANDARCHIVE.fields_by_name['undo_object_for_commit'].message_type = TSPMessages__pb2._REFERENCE
_CONTAINEDOBJECTSCOMMANDARCHIVE.fields_by_name['undo_object_for_make_inverse'].message_type = TSPMessages__pb2._REFERENCE
_CONTAINEDOBJECTSCOMMANDARCHIVE.fields_by_name['add_behavior_args'].message_type = _CONTAINEDOBJECTSCOMMANDARCHIVE_ADDBEHAVIORARGS
_CONTAINEDOBJECTSCOMMANDARCHIVE.fields_by_name['remove_behavior_args'].message_type = _CONTAINEDOBJECTSCOMMANDARCHIVE_REMOVEBEHAVIORARGS
_CONTAINEDOBJECTSCOMMANDARCHIVE.fields_by_name['rearrange_behavior_args'].message_type = _CONTAINEDOBJECTSCOMMANDARCHIVE_REARRANGEBEHAVIORARGS
_CONTAINEDOBJECTSCOMMANDARCHIVE.oneofs_by_name['undo_object'].fields.append(
  _CONTAINEDOBJECTSCOMMANDARCHIVE.fields_by_name['undo_object_for_commit'])
_CONTAINEDOBJECTSCOMMANDARCHIVE.fields_by_name['undo_object_for_commit'].containing_oneof = _CONTAINEDOBJECTSCOMMANDARCHIVE.oneofs_by_name['undo_object']
_CONTAINEDOBJECTSCOMMANDARCHIVE.oneofs_by_name['undo_object'].fields.append(
  _CONTAINEDOBJECTSCOMMANDARCHIVE.fields_by_name['undo_object_for_make_inverse'])
_CONTAINEDOBJECTSCOMMANDARCHIVE.fields_by_name['undo_object_for_make_inverse'].containing_oneof = _CONTAINEDOBJECTSCOMMANDARCHIVE.oneofs_by_name['undo_object']
_CONTAINEDOBJECTSCOMMANDARCHIVE.oneofs_by_name['behavior'].fields.append(
  _CONTAINEDOBJECTSCOMMANDARCHIVE.fields_by_name['add_behavior_args'])
_CONTAINEDOBJECTSCOMMANDARCHIVE.fields_by_name['add_behavior_args'].containing_oneof = _CONTAINEDOBJECTSCOMMANDARCHIVE.oneofs_by_name['behavior']
_CONTAINEDOBJECTSCOMMANDARCHIVE.oneofs_by_name['behavior'].fields.append(
  _CONTAINEDOBJECTSCOMMANDARCHIVE.fields_by_name['remove_behavior_args'])
_CONTAINEDOBJECTSCOMMANDARCHIVE.fields_by_name['remove_behavior_args'].containing_oneof = _CONTAINEDOBJECTSCOMMANDARCHIVE.oneofs_by_name['behavior']
_CONTAINEDOBJECTSCOMMANDARCHIVE.oneofs_by_name['behavior'].fields.append(
  _CONTAINEDOBJECTSCOMMANDARCHIVE.fields_by_name['rearrange_behavior_args'])
_CONTAINEDOBJECTSCOMMANDARCHIVE.fields_by_name['rearrange_behavior_args'].containing_oneof = _CONTAINEDOBJECTSCOMMANDARCHIVE.oneofs_by_name['behavior']
_EQUATIONINFOGEOMETRYCOMMANDARCHIVE.fields_by_name['super'].message_type = TSDCommandArchives__pb2._MEDIAINFOGEOMETRYCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['DummyCommandArchive'] = _DUMMYCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['TextCommandArchive'] = _TEXTCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['StorageActionCommandArchive'] = _STORAGEACTIONCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['SetColumnStyleCommandArchive'] = _SETCOLUMNSTYLECOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['ReplaceAllUsesOfStyleCommandArchive'] = _REPLACEALLUSESOFSTYLECOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['InsertColumnsCommandArchive'] = _INSERTCOLUMNSCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['InsertRowsCommandArchive'] = _INSERTROWSCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['RemoveColumnsCommandArchive'] = _REMOVECOLUMNSCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['RemoveRowsCommandArchive'] = _REMOVEROWSCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['MergeCellsCommandArchive'] = _MERGECELLSCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['ApplyPlaceholderTextCommandArchive'] = _APPLYPLACEHOLDERTEXTCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['UpdateDateTimeFieldCommandArchive'] = _UPDATEDATETIMEFIELDCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['ApplyRubyTextCommandArchive'] = _APPLYRUBYTEXTCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['ModifyRubyTextCommandArchive'] = _MODIFYRUBYTEXTCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['ModifyTOCSettingsBaseCommandArchive'] = _MODIFYTOCSETTINGSBASECOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['ModifyTOCSettingsForTOCInfoCommandArchive'] = _MODIFYTOCSETTINGSFORTOCINFOCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['ModifyTOCSettingsPresetForThemeCommandArchive'] = _MODIFYTOCSETTINGSPRESETFORTHEMECOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['AnchorAttachmentCommandArchive'] = _ANCHORATTACHMENTCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['TextApplyThemeCommandArchive'] = _TEXTAPPLYTHEMECOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['MoveColumnsCommandArchive'] = _MOVECOLUMNSCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['MoveRowsCommandArchive'] = _MOVEROWSCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['ShapeApplyPresetCommandArchive'] = _SHAPEAPPLYPRESETCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['StyleBaseCommandArchive'] = _STYLEBASECOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['StyleCreateCommandArchive'] = _STYLECREATECOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['StyleRenameCommandArchive'] = _STYLERENAMECOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['StyleUpdateCommandArchive'] = _STYLEUPDATECOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['StyleDeleteCommandArchive'] = _STYLEDELETECOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['StyleReorderCommandArchive'] = _STYLEREORDERCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['StyleUpdatePropertyMapCommandArchive'] = _STYLEUPDATEPROPERTYMAPCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['ShapeStyleSetValueCommandArchive'] = _SHAPESTYLESETVALUECOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['SelectionTransformerArchive'] = _SELECTIONTRANSFORMERARCHIVE
DESCRIPTOR.message_types_by_name['PencilAnnotationSelectionTransformerArchive'] = _PENCILANNOTATIONSELECTIONTRANSFORMERARCHIVE
DESCRIPTOR.message_types_by_name['ShapeSelectionTransformerArchive'] = _SHAPESELECTIONTRANSFORMERARCHIVE
DESCRIPTOR.message_types_by_name['ShapeContentDescription'] = _SHAPECONTENTDESCRIPTION
DESCRIPTOR.message_types_by_name['ObjectPropertyArchive'] = _OBJECTPROPERTYARCHIVE
DESCRIPTOR.message_types_by_name['SetObjectPropertiesCommandArchive'] = _SETOBJECTPROPERTIESCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['UpdateFlowInfoCommandArchive'] = _UPDATEFLOWINFOCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['AddFlowInfoCommandArchive'] = _ADDFLOWINFOCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['RemoveFlowInfoCommandArchive'] = _REMOVEFLOWINFOCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['TextCommentReplyCommandArchive'] = _TEXTCOMMENTREPLYCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['ContainedObjectsCommandArchive'] = _CONTAINEDOBJECTSCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['EquationInfoGeometryCommandArchive'] = _EQUATIONINFOGEOMETRYCOMMANDARCHIVE
DESCRIPTOR.enum_types_by_name['ObjectPropertyType'] = _OBJECTPROPERTYTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DummyCommandArchive = _reflection.GeneratedProtocolMessageType('DummyCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _DUMMYCOMMANDARCHIVE,
  __module__ = 'TSWPCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.DummyCommandArchive)
  ))
_sym_db.RegisterMessage(DummyCommandArchive)

TextCommandArchive = _reflection.GeneratedProtocolMessageType('TextCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _TEXTCOMMANDARCHIVE,
  __module__ = 'TSWPCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.TextCommandArchive)
  ))
_sym_db.RegisterMessage(TextCommandArchive)

StorageActionCommandArchive = _reflection.GeneratedProtocolMessageType('StorageActionCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _STORAGEACTIONCOMMANDARCHIVE,
  __module__ = 'TSWPCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.StorageActionCommandArchive)
  ))
_sym_db.RegisterMessage(StorageActionCommandArchive)

SetColumnStyleCommandArchive = _reflection.GeneratedProtocolMessageType('SetColumnStyleCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _SETCOLUMNSTYLECOMMANDARCHIVE,
  __module__ = 'TSWPCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.SetColumnStyleCommandArchive)
  ))
_sym_db.RegisterMessage(SetColumnStyleCommandArchive)

ReplaceAllUsesOfStyleCommandArchive = _reflection.GeneratedProtocolMessageType('ReplaceAllUsesOfStyleCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _REPLACEALLUSESOFSTYLECOMMANDARCHIVE,
  __module__ = 'TSWPCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.ReplaceAllUsesOfStyleCommandArchive)
  ))
_sym_db.RegisterMessage(ReplaceAllUsesOfStyleCommandArchive)

InsertColumnsCommandArchive = _reflection.GeneratedProtocolMessageType('InsertColumnsCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _INSERTCOLUMNSCOMMANDARCHIVE,
  __module__ = 'TSWPCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.InsertColumnsCommandArchive)
  ))
_sym_db.RegisterMessage(InsertColumnsCommandArchive)

InsertRowsCommandArchive = _reflection.GeneratedProtocolMessageType('InsertRowsCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _INSERTROWSCOMMANDARCHIVE,
  __module__ = 'TSWPCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.InsertRowsCommandArchive)
  ))
_sym_db.RegisterMessage(InsertRowsCommandArchive)

RemoveColumnsCommandArchive = _reflection.GeneratedProtocolMessageType('RemoveColumnsCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _REMOVECOLUMNSCOMMANDARCHIVE,
  __module__ = 'TSWPCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.RemoveColumnsCommandArchive)
  ))
_sym_db.RegisterMessage(RemoveColumnsCommandArchive)

RemoveRowsCommandArchive = _reflection.GeneratedProtocolMessageType('RemoveRowsCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _REMOVEROWSCOMMANDARCHIVE,
  __module__ = 'TSWPCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.RemoveRowsCommandArchive)
  ))
_sym_db.RegisterMessage(RemoveRowsCommandArchive)

MergeCellsCommandArchive = _reflection.GeneratedProtocolMessageType('MergeCellsCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _MERGECELLSCOMMANDARCHIVE,
  __module__ = 'TSWPCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.MergeCellsCommandArchive)
  ))
_sym_db.RegisterMessage(MergeCellsCommandArchive)

ApplyPlaceholderTextCommandArchive = _reflection.GeneratedProtocolMessageType('ApplyPlaceholderTextCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _APPLYPLACEHOLDERTEXTCOMMANDARCHIVE,
  __module__ = 'TSWPCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.ApplyPlaceholderTextCommandArchive)
  ))
_sym_db.RegisterMessage(ApplyPlaceholderTextCommandArchive)

UpdateDateTimeFieldCommandArchive = _reflection.GeneratedProtocolMessageType('UpdateDateTimeFieldCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _UPDATEDATETIMEFIELDCOMMANDARCHIVE,
  __module__ = 'TSWPCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.UpdateDateTimeFieldCommandArchive)
  ))
_sym_db.RegisterMessage(UpdateDateTimeFieldCommandArchive)

ApplyRubyTextCommandArchive = _reflection.GeneratedProtocolMessageType('ApplyRubyTextCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _APPLYRUBYTEXTCOMMANDARCHIVE,
  __module__ = 'TSWPCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.ApplyRubyTextCommandArchive)
  ))
_sym_db.RegisterMessage(ApplyRubyTextCommandArchive)

ModifyRubyTextCommandArchive = _reflection.GeneratedProtocolMessageType('ModifyRubyTextCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _MODIFYRUBYTEXTCOMMANDARCHIVE,
  __module__ = 'TSWPCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.ModifyRubyTextCommandArchive)
  ))
_sym_db.RegisterMessage(ModifyRubyTextCommandArchive)

ModifyTOCSettingsBaseCommandArchive = _reflection.GeneratedProtocolMessageType('ModifyTOCSettingsBaseCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _MODIFYTOCSETTINGSBASECOMMANDARCHIVE,
  __module__ = 'TSWPCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.ModifyTOCSettingsBaseCommandArchive)
  ))
_sym_db.RegisterMessage(ModifyTOCSettingsBaseCommandArchive)

ModifyTOCSettingsForTOCInfoCommandArchive = _reflection.GeneratedProtocolMessageType('ModifyTOCSettingsForTOCInfoCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _MODIFYTOCSETTINGSFORTOCINFOCOMMANDARCHIVE,
  __module__ = 'TSWPCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.ModifyTOCSettingsForTOCInfoCommandArchive)
  ))
_sym_db.RegisterMessage(ModifyTOCSettingsForTOCInfoCommandArchive)

ModifyTOCSettingsPresetForThemeCommandArchive = _reflection.GeneratedProtocolMessageType('ModifyTOCSettingsPresetForThemeCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _MODIFYTOCSETTINGSPRESETFORTHEMECOMMANDARCHIVE,
  __module__ = 'TSWPCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.ModifyTOCSettingsPresetForThemeCommandArchive)
  ))
_sym_db.RegisterMessage(ModifyTOCSettingsPresetForThemeCommandArchive)

AnchorAttachmentCommandArchive = _reflection.GeneratedProtocolMessageType('AnchorAttachmentCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _ANCHORATTACHMENTCOMMANDARCHIVE,
  __module__ = 'TSWPCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.AnchorAttachmentCommandArchive)
  ))
_sym_db.RegisterMessage(AnchorAttachmentCommandArchive)

TextApplyThemeCommandArchive = _reflection.GeneratedProtocolMessageType('TextApplyThemeCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _TEXTAPPLYTHEMECOMMANDARCHIVE,
  __module__ = 'TSWPCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.TextApplyThemeCommandArchive)
  ))
_sym_db.RegisterMessage(TextApplyThemeCommandArchive)

MoveColumnsCommandArchive = _reflection.GeneratedProtocolMessageType('MoveColumnsCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _MOVECOLUMNSCOMMANDARCHIVE,
  __module__ = 'TSWPCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.MoveColumnsCommandArchive)
  ))
_sym_db.RegisterMessage(MoveColumnsCommandArchive)

MoveRowsCommandArchive = _reflection.GeneratedProtocolMessageType('MoveRowsCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _MOVEROWSCOMMANDARCHIVE,
  __module__ = 'TSWPCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.MoveRowsCommandArchive)
  ))
_sym_db.RegisterMessage(MoveRowsCommandArchive)

ShapeApplyPresetCommandArchive = _reflection.GeneratedProtocolMessageType('ShapeApplyPresetCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _SHAPEAPPLYPRESETCOMMANDARCHIVE,
  __module__ = 'TSWPCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.ShapeApplyPresetCommandArchive)
  ))
_sym_db.RegisterMessage(ShapeApplyPresetCommandArchive)

StyleBaseCommandArchive = _reflection.GeneratedProtocolMessageType('StyleBaseCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _STYLEBASECOMMANDARCHIVE,
  __module__ = 'TSWPCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.StyleBaseCommandArchive)
  ))
_sym_db.RegisterMessage(StyleBaseCommandArchive)

StyleCreateCommandArchive = _reflection.GeneratedProtocolMessageType('StyleCreateCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _STYLECREATECOMMANDARCHIVE,
  __module__ = 'TSWPCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.StyleCreateCommandArchive)
  ))
_sym_db.RegisterMessage(StyleCreateCommandArchive)

StyleRenameCommandArchive = _reflection.GeneratedProtocolMessageType('StyleRenameCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _STYLERENAMECOMMANDARCHIVE,
  __module__ = 'TSWPCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.StyleRenameCommandArchive)
  ))
_sym_db.RegisterMessage(StyleRenameCommandArchive)

StyleUpdateCommandArchive = _reflection.GeneratedProtocolMessageType('StyleUpdateCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _STYLEUPDATECOMMANDARCHIVE,
  __module__ = 'TSWPCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.StyleUpdateCommandArchive)
  ))
_sym_db.RegisterMessage(StyleUpdateCommandArchive)

StyleDeleteCommandArchive = _reflection.GeneratedProtocolMessageType('StyleDeleteCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _STYLEDELETECOMMANDARCHIVE,
  __module__ = 'TSWPCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.StyleDeleteCommandArchive)
  ))
_sym_db.RegisterMessage(StyleDeleteCommandArchive)

StyleReorderCommandArchive = _reflection.GeneratedProtocolMessageType('StyleReorderCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _STYLEREORDERCOMMANDARCHIVE,
  __module__ = 'TSWPCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.StyleReorderCommandArchive)
  ))
_sym_db.RegisterMessage(StyleReorderCommandArchive)

StyleUpdatePropertyMapCommandArchive = _reflection.GeneratedProtocolMessageType('StyleUpdatePropertyMapCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _STYLEUPDATEPROPERTYMAPCOMMANDARCHIVE,
  __module__ = 'TSWPCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.StyleUpdatePropertyMapCommandArchive)
  ))
_sym_db.RegisterMessage(StyleUpdatePropertyMapCommandArchive)

ShapeStyleSetValueCommandArchive = _reflection.GeneratedProtocolMessageType('ShapeStyleSetValueCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _SHAPESTYLESETVALUECOMMANDARCHIVE,
  __module__ = 'TSWPCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.ShapeStyleSetValueCommandArchive)
  ))
_sym_db.RegisterMessage(ShapeStyleSetValueCommandArchive)

SelectionTransformerArchive = _reflection.GeneratedProtocolMessageType('SelectionTransformerArchive', (_message.Message,), dict(
  DESCRIPTOR = _SELECTIONTRANSFORMERARCHIVE,
  __module__ = 'TSWPCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.SelectionTransformerArchive)
  ))
_sym_db.RegisterMessage(SelectionTransformerArchive)

PencilAnnotationSelectionTransformerArchive = _reflection.GeneratedProtocolMessageType('PencilAnnotationSelectionTransformerArchive', (_message.Message,), dict(
  DESCRIPTOR = _PENCILANNOTATIONSELECTIONTRANSFORMERARCHIVE,
  __module__ = 'TSWPCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.PencilAnnotationSelectionTransformerArchive)
  ))
_sym_db.RegisterMessage(PencilAnnotationSelectionTransformerArchive)

ShapeSelectionTransformerArchive = _reflection.GeneratedProtocolMessageType('ShapeSelectionTransformerArchive', (_message.Message,), dict(
  DESCRIPTOR = _SHAPESELECTIONTRANSFORMERARCHIVE,
  __module__ = 'TSWPCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.ShapeSelectionTransformerArchive)
  ))
_sym_db.RegisterMessage(ShapeSelectionTransformerArchive)

ShapeContentDescription = _reflection.GeneratedProtocolMessageType('ShapeContentDescription', (_message.Message,), dict(
  DESCRIPTOR = _SHAPECONTENTDESCRIPTION,
  __module__ = 'TSWPCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.ShapeContentDescription)
  ))
_sym_db.RegisterMessage(ShapeContentDescription)

ObjectPropertyArchive = _reflection.GeneratedProtocolMessageType('ObjectPropertyArchive', (_message.Message,), dict(
  DESCRIPTOR = _OBJECTPROPERTYARCHIVE,
  __module__ = 'TSWPCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.ObjectPropertyArchive)
  ))
_sym_db.RegisterMessage(ObjectPropertyArchive)

SetObjectPropertiesCommandArchive = _reflection.GeneratedProtocolMessageType('SetObjectPropertiesCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _SETOBJECTPROPERTIESCOMMANDARCHIVE,
  __module__ = 'TSWPCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.SetObjectPropertiesCommandArchive)
  ))
_sym_db.RegisterMessage(SetObjectPropertiesCommandArchive)

UpdateFlowInfoCommandArchive = _reflection.GeneratedProtocolMessageType('UpdateFlowInfoCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _UPDATEFLOWINFOCOMMANDARCHIVE,
  __module__ = 'TSWPCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.UpdateFlowInfoCommandArchive)
  ))
_sym_db.RegisterMessage(UpdateFlowInfoCommandArchive)

AddFlowInfoCommandArchive = _reflection.GeneratedProtocolMessageType('AddFlowInfoCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _ADDFLOWINFOCOMMANDARCHIVE,
  __module__ = 'TSWPCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.AddFlowInfoCommandArchive)
  ))
_sym_db.RegisterMessage(AddFlowInfoCommandArchive)

RemoveFlowInfoCommandArchive = _reflection.GeneratedProtocolMessageType('RemoveFlowInfoCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _REMOVEFLOWINFOCOMMANDARCHIVE,
  __module__ = 'TSWPCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.RemoveFlowInfoCommandArchive)
  ))
_sym_db.RegisterMessage(RemoveFlowInfoCommandArchive)

TextCommentReplyCommandArchive = _reflection.GeneratedProtocolMessageType('TextCommentReplyCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _TEXTCOMMENTREPLYCOMMANDARCHIVE,
  __module__ = 'TSWPCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.TextCommentReplyCommandArchive)
  ))
_sym_db.RegisterMessage(TextCommentReplyCommandArchive)

ContainedObjectsCommandArchive = _reflection.GeneratedProtocolMessageType('ContainedObjectsCommandArchive', (_message.Message,), dict(

  AddBehaviorArgs = _reflection.GeneratedProtocolMessageType('AddBehaviorArgs', (_message.Message,), dict(
    DESCRIPTOR = _CONTAINEDOBJECTSCOMMANDARCHIVE_ADDBEHAVIORARGS,
    __module__ = 'TSWPCommandArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSWP.ContainedObjectsCommandArchive.AddBehaviorArgs)
    ))
  ,

  RemoveBehaviorArgs = _reflection.GeneratedProtocolMessageType('RemoveBehaviorArgs', (_message.Message,), dict(
    DESCRIPTOR = _CONTAINEDOBJECTSCOMMANDARCHIVE_REMOVEBEHAVIORARGS,
    __module__ = 'TSWPCommandArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSWP.ContainedObjectsCommandArchive.RemoveBehaviorArgs)
    ))
  ,

  RearrangeBehaviorArgs = _reflection.GeneratedProtocolMessageType('RearrangeBehaviorArgs', (_message.Message,), dict(
    DESCRIPTOR = _CONTAINEDOBJECTSCOMMANDARCHIVE_REARRANGEBEHAVIORARGS,
    __module__ = 'TSWPCommandArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSWP.ContainedObjectsCommandArchive.RearrangeBehaviorArgs)
    ))
  ,
  DESCRIPTOR = _CONTAINEDOBJECTSCOMMANDARCHIVE,
  __module__ = 'TSWPCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.ContainedObjectsCommandArchive)
  ))
_sym_db.RegisterMessage(ContainedObjectsCommandArchive)
_sym_db.RegisterMessage(ContainedObjectsCommandArchive.AddBehaviorArgs)
_sym_db.RegisterMessage(ContainedObjectsCommandArchive.RemoveBehaviorArgs)
_sym_db.RegisterMessage(ContainedObjectsCommandArchive.RearrangeBehaviorArgs)

EquationInfoGeometryCommandArchive = _reflection.GeneratedProtocolMessageType('EquationInfoGeometryCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _EQUATIONINFOGEOMETRYCOMMANDARCHIVE,
  __module__ = 'TSWPCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSWP.EquationInfoGeometryCommandArchive)
  ))
_sym_db.RegisterMessage(EquationInfoGeometryCommandArchive)


# @@protoc_insertion_point(module_scope)
